==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/formmanagerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>EpisodeModel</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="567"/>
        <source>Save episode?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="568"/>
        <source>The actual episode has been modified. Do you want to save changes in your database?
Answering &apos;No&apos; will cause definitve data lose.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="570"/>
        <source>Save episode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::EpisodeModel</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="989"/>
        <source>Created: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="1106"/>
        <source>New episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/episodemodel.cpp" line="1319"/>
        <source>No user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormEditorDialog</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.ui" line="32"/>
        <source>Patient Form Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.ui" line="106"/>
        <source>Add this form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.cpp" line="79"/>
        <source>Form Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.cpp" line="94"/>
        <source>Insert as root form?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formeditordialog.cpp" line="94"/>
        <source>You did not selected a form, do you want to add the sub-form as root form?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormFilesSelectorWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="28"/>
        <source>View by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.ui" line="61"/>
        <source>Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMain</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="653"/>
        <source>Form: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMainDebugPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformitem.cpp" line="779"/>
        <source>Forms: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FirstRunFormManagerWizardPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="52"/>
        <source>General patient form selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="53"/>
        <source>You can define your own patient form file, or use the default one. Select it from here. All patients will have the same forms, but you can add subforms anywhere in the form.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="61"/>
        <source>Reading available forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="61"/>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="84"/>
        <source>Please one (and only one) form for your default patient file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/firstrunformmanager.cpp" line="85"/>
        <source>You must select one file to be used by default.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerMode</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagermode.cpp" line="67"/>
        <location filename="../../plugins/formmanagerplugin/formmanagermode.cpp" line="93"/>
        <source>Patients Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerPlugin</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerplugin.cpp" line="105"/>
        <location filename="../../plugins/formmanagerplugin/formmanagerplugin.cpp" line="121"/>
        <source>Initializing form manager plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesFileSelectorPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="73"/>
        <source>Patient file form selector</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesFileSelectorWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferenceswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferenceswidget.ui" line="30"/>
        <source>Use the selected form for all patients</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesPage</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="167"/>
        <source>Form and episode tree viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="20"/>
        <source>Colors in the view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="26"/>
        <source>Use alternate row colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="33"/>
        <source>Use specific foreground for root forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="40"/>
        <source>Select the foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="85"/>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="129"/>
        <source>Episode presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="135"/>
        <source>Select label content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="152"/>
        <source>Long date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formpreferenceswidget.ui" line="162"/>
        <source>Short date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="240"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="241"/>
        <source>Label - User date (small)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="242"/>
        <source>Label - User date (full)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="243"/>
        <source>User date (small)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="244"/>
        <source>User date (full)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="245"/>
        <source>User date (small) - Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formmanagerpreferencespage.cpp" line="246"/>
        <source>User date (full) - Label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormFilesSelectorWidget</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="93"/>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="94"/>
        <source>by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="99"/>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="100"/>
        <source>by author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="105"/>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="106"/>
        <source>by specialty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="111"/>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="112"/>
        <source>by type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/formfilesselectorwidget.cpp" line="161"/>
        <source>Default Forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormIODescription</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="120"/>
        <source>Complete form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="122"/>
        <source>Sub-form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="124"/>
        <source>Page only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Forms</name>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="157"/>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="183"/>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="159"/>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="185"/>
        <source>Last modification date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/iformio.cpp" line="196"/>
        <source>ScreenShots are available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="110"/>
        <source>Add Episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="111"/>
        <source>Validate Episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="112"/>
        <source>Add Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="113"/>
        <source>Print Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="114"/>
        <source>Show patients&apos; synthesis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="115"/>
        <source>Show patients&apos; last episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="116"/>
        <source>Patients&apos; last episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="118"/>
        <source>Forms font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/formmanagerplugin/constants_db.h" line="119"/>
        <source>Episodes font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/formmanagerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Form::EpisodeModel</name>
    <message>
        <source>Xml content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New episode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormEditorDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Patient Form Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add this form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Form Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert as root form?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You did not selected a form, do you want to add the sub-form as root form?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For current patient only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For all patients</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormFilesSelectorWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMain</name>
    <message>
        <source>Form: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormMainDebugPage</name>
    <message>
        <source>Forms: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::FormPlaceHolder</name>
    <message>
        <source>Save episode?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The actual episode has been modified. Do you want to save changes in your database?
Answering &apos;No&apos; will cause definitve data loss.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Validate the current episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When you validate an episode, you prevent all subsequent amendments. The episode will be shown but will be kept unchanged.
Do you really want to validate the current episode?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the current episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can not completely destroy an episode, but you can remove it from the views.
The episode will not be shown anymore, but will still be included in the database.
Do you really want to remove the current episode?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images (*.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the current form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trying to remove the sub-form:&lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;.&lt;br /&gt;&lt;br /&gt;%2This modification will only affect the current patient:&lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%3&lt;/b&gt;.&lt;br /&gt;&lt;br /&gt;Do you really want to remove the current sub-form?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::EpisodeBase</name>
    <message>
        <source>Unable to update the database schema</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode database updated from version %1 to version: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FirstRunFormManagerWizardPage</name>
    <message>
        <source>General patient form selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can define your own patient form file, or use the default one. Select it from here. All patients will have the same forms, but you can add subforms anywhere in the form.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading available forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please one (and only one) form for your default patient file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select one file to be used by default.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerMode</name>
    <message>
        <source>Patients Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormManagerPlugin</name>
    <message>
        <source>Initializing form manager plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPlaceHolder</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesFileSelectorPage</name>
    <message>
        <source>Patient file form selector</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesFileSelectorWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the selected form for all patients</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesPage</name>
    <message>
        <source>Form and episode tree viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Form::Internal::FormPreferencesWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors in the view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use alternate row colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use specific foreground for root forms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episode presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select label content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Long date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label - User date (small)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label - User date (full)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User date (small)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User date (full)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User date (small) - Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User date (full) - Label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormFilesSelectorWidget</name>
    <message>
        <source>by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by specialty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Forms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FormIODescription</name>
    <message>
        <source>Complete form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sub-form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Forms</name>
    <message>
        <source>Add Episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Validate Episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show patients&apos; synthesis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show patients&apos; last episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Patients&apos; last episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forms font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episodes font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last modification date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ScreenShots are available.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
